@@ -36,13 +36,12 @@
 #include <kjobtrackerinterface.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <KStandardDirs>
 #include <kio/job.h>
 
 #include <QFileInfo>
 #include <QDir>
-#include <QPointer>
 #include <QTimer>
+#include <QWeakPointer>
 
 namespace Kerfuffle
 {
@@ -77,23 +76,23 @@ void AddToArchive::setMimeType(const QString & mimeType)
 
 bool AddToArchive::showAddDialog(void)
 {
-    QPointer<Kerfuffle::AddDialog> dialog = new Kerfuffle::AddDialog(
+    QWeakPointer<Kerfuffle::AddDialog> dialog = new Kerfuffle::AddDialog(
         m_inputs, // itemsToAdd
         KUrl(m_firstPath), // startDir
-        "", // filter
+        QLatin1String( "" ), // filter
         NULL, // parent
         NULL); // widget
 
-    bool ret = dialog->exec();
+    bool ret = dialog.data()->exec();
 
     if (ret) {
-        kDebug() << "Returned URL:" << dialog->selectedUrl();
-        kDebug() << "Returned mime:" << dialog->currentMimeFilter();
-        setFilename(dialog->selectedUrl());
-        setMimeType(dialog->currentMimeFilter());
+        kDebug() << "Returned URL:" << dialog.data()->selectedUrl();
+        kDebug() << "Returned mime:" << dialog.data()->currentMimeFilter();
+        setFilename(dialog.data()->selectedUrl());
+        setMimeType(dialog.data()->currentMimeFilter());
     }
 
-    delete dialog;
+    delete dialog.data();
 
     return ret;
 }
@@ -135,10 +134,10 @@ void AddToArchive::slotStartJob(void)
     Kerfuffle::Archive *archive;
     if (!m_filename.isEmpty()) {
         archive = Kerfuffle::factory(m_filename, m_mimeType);
-        kDebug() << "Set filename to " + m_filename;
+        kDebug() << "Set filename to " << m_filename;
     } else {
         if (m_autoFilenameSuffix.isEmpty()) {
-            KMessageBox::error(NULL, i18n("You need to either supply a filename for the archive or a suffix (such as rar, tar.gz) with the --autofilename argument."));
+            KMessageBox::error(NULL, i18n("You need to either supply a filename for the archive or a suffix (such as rar, tar.gz) with the <command>--autofilename</command> argument."));
             return;
         }
 
@@ -147,26 +146,22 @@ void AddToArchive::slotStartJob(void)
             return;
         }
 
-        QString base;
-        QFileInfo fi(m_inputs.first());
-
-        base = fi.absoluteFilePath();
-
-        if (base.endsWith('/')) {
+        QString base = QFileInfo(m_inputs.first()).absoluteFilePath();
+        if (base.endsWith(QLatin1Char('/'))) {
             base.chop(1);
         }
 
-        QString finalName = base + '.' + m_autoFilenameSuffix;
+        QString finalName = base + QLatin1Char( '.' ) + m_autoFilenameSuffix;
 
         //if file already exists, append a number to the base until it doesn't
         //exist
         int appendNumber = 0;
-        while (KStandardDirs::exists(finalName)) {
+        while (QFileInfo(finalName).exists()) {
             ++appendNumber;
-            finalName = base + '_' + QString::number(appendNumber) + '.' + m_autoFilenameSuffix;
+            finalName = base + QLatin1Char( '_' ) + QString::number(appendNumber) + QLatin1Char( '.' ) + m_autoFilenameSuffix;
         }
 
-        kDebug() << "Autoset filename to " + finalName;
+        kDebug() << "Autoset filename to "<< finalName;
         archive = Kerfuffle::factory(finalName, m_mimeType);
     }
 
@@ -190,7 +185,7 @@ void AddToArchive::slotStartJob(void)
             m_inputs[i] = stripDir.absoluteFilePath(m_inputs.at(i));
         }
 
-        options["GlobalWorkDir"] = stripDir.path();
+        options[QLatin1String( "GlobalWorkDir" )] = stripDir.path();
         kDebug() << "Setting GlobalWorkDir to " << stripDir.path();
     }
 
