@@ -87,7 +87,7 @@ bool CliInterface::list()
 
 bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options)
 {
-    kDebug() ;
+    kDebug();
     cacheParameterList();
 
     m_operationMode = Copy;
@@ -105,32 +105,33 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
         QString argument = args.at(i);
         kDebug() << "Processing argument " << argument;
 
-        if (argument == "$Archive") {
+        if (argument == QLatin1String( "$Archive" )) {
             args[i] = filename();
         }
 
-        if (argument == "$PreservePathSwitch") {
-
+        if (argument == QLatin1String( "$PreservePathSwitch" )) {
             QStringList replacementFlags = m_param.value(PreservePathSwitch).toStringList();
             Q_ASSERT(replacementFlags.size() == 2);
 
-            bool preservePaths = options.value("PreservePaths").toBool();
+            bool preservePaths = options.value(QLatin1String( "PreservePaths" )).toBool();
             QString theReplacement;
-            if (preservePaths)
+            if (preservePaths) {
                 theReplacement = replacementFlags.at(0);
-            else
+            } else {
                 theReplacement = replacementFlags.at(1);
+            }
 
             if (theReplacement.isEmpty()) {
                 args.removeAt(i);
                 --i; //decrement to compensate for the variable we removed
-            } else
+            } else {
                 //but in this case we don't have to decrement, we just
                 //replace it
                 args[i] = theReplacement;
+            }
         }
 
-        if (argument == "$PasswordSwitch") {
+        if (argument == QLatin1String( "$PasswordSwitch" )) {
             //if the PasswordSwitch argument has been added, we at least
             //assume that the format of the switch has been added as well
             Q_ASSERT(m_param.contains(PasswordSwitch));
@@ -140,7 +141,8 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
 
             //if we get a hint about this being a password protected archive, ask about
             //the password in advance.
-            if (options.value("PasswordProtectedHint").toBool() && password().isEmpty()) {
+            if ((options.value(QLatin1String("PasswordProtectedHint")).toBool()) &&
+                (password().isEmpty())) {
                 kDebug() << "Password hint enabled, querying user";
 
                 Kerfuffle::PasswordNeededQuery query(filename());
@@ -163,7 +165,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
                     QString newArg = theSwitch.at(j);
 
                     //substitute the $Path
-                    newArg.replace("$Password", pass);
+                    newArg.replace(QLatin1String( "$Password" ), pass);
 
                     //put it in the arg list
                     args.insert(i + j, newArg);
@@ -174,7 +176,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
             --i; //decrement to compensate for the variable we replaced
         }
 
-        if (argument == "$RootNodeSwitch") {
+        if (argument == QLatin1String( "$RootNodeSwitch" )) {
             //if the RootNodeSwitch argument has been added, we at least
             //assume that the format of the switch has been added as well
             Q_ASSERT(m_param.contains(RootNodeSwitch));
@@ -183,8 +185,8 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
             args.removeAt(i);
 
             QString rootNode;
-            if (options.contains("RootNode")) {
-                rootNode = options.value("RootNode").toString();
+            if (options.contains(QLatin1String( "RootNode" ))) {
+                rootNode = options.value(QLatin1String( "RootNode" )).toString();
                 kDebug() << "Set root node " << rootNode;
             }
 
@@ -195,7 +197,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
                     QString newArg = theSwitch.at(j);
 
                     //substitute the $Path
-                    newArg.replace("$Path", rootNode);
+                    newArg.replace(QLatin1String( "$Path" ), rootNode);
 
                     //put it in the arg list
                     args.insert(i + j, newArg);
@@ -206,7 +208,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
             --i; //decrement to compensate for the variable we replaced
         }
 
-        if (argument == "$Files") {
+        if (argument == QLatin1String( "$Files" )) {
             args.removeAt(i);
             for (int j = 0; j < files.count(); ++j) {
                 args.insert(i + j, escapeFileName(files.at(j).toString()));
@@ -235,7 +237,7 @@ bool CliInterface::addFiles(const QStringList & files, const CompressionOptions&
         return false;
     }
 
-    const QString globalWorkDir = options.value("GlobalWorkDir").toString();
+    const QString globalWorkDir = options.value(QLatin1String( "GlobalWorkDir" )).toString();
     const QDir workDir = globalWorkDir.isEmpty() ? QDir::current() : QDir(globalWorkDir);
     if (!globalWorkDir.isEmpty()) {
         kDebug() << "GlobalWorkDir is set, changing dir to " << globalWorkDir;
@@ -250,11 +252,11 @@ bool CliInterface::addFiles(const QStringList & files, const CompressionOptions&
         const QString argument = args.at(i);
         kDebug() << "Processing argument " << argument;
 
-        if (argument == "$Archive") {
+        if (argument == QLatin1String( "$Archive" )) {
             args[i] = filename();
         }
 
-        if (argument == "$Files") {
+        if (argument == QLatin1String( "$Files" )) {
             args.removeAt(i);
             for (int j = 0; j < files.count(); ++j) {
                 // #191821: workDir must be used instead of QDir::current()
@@ -294,11 +296,9 @@ bool CliInterface::deleteFiles(const QList<QVariant> & files)
         QString argument = args.at(i);
         kDebug() << "Processing argument " << argument;
 
-        if (argument == "$Archive") {
+        if (argument == QLatin1String( "$Archive" )) {
             args[i] = filename();
-        }
-
-        if (argument == "$Files") {
+        } else if (argument == QLatin1String( "$Files" )) {
             args.removeAt(i);
             for (int j = 0; j < files.count(); ++j) {
                 args.insert(i + j, escapeFileName(files.at(j).toString()));
@@ -330,8 +330,9 @@ bool CliInterface::createProcess()
     m_process->setTextModeEnabled(true);
     m_process->setOutputChannelMode(KProcess::MergedChannels);
 
-    if (QMetaType::type("QProcess::ExitStatus") == 0)
+    if (QMetaType::type("QProcess::ExitStatus") == 0) {
         qRegisterMetaType<QProcess::ExitStatus>("QProcess::ExitStatus");
+    }
 
     connect(m_process, SIGNAL(started()), SLOT(started()), Qt::DirectConnection);
     connect(m_process, SIGNAL(readyReadStandardOutput()), SLOT(readStdout()), Qt::DirectConnection);
@@ -367,8 +368,9 @@ void CliInterface::processFinished(int exitCode, QProcess::ExitStatus exitStatus
 
     //if the m_process pointer is gone, then there is nothing to worry
     //about here
-    if (!m_process)
+    if (!m_process) {
         return;
+    }
 
     if (m_operationMode == Delete) {
         foreach(const QVariant& v, m_removedFiles) {
@@ -394,8 +396,7 @@ void CliInterface::failOperation()
 {
     kDebug();
 
-    if (m_process)
-        m_process->terminate();
+    doKill();
 
     finished(false);
 }
@@ -432,12 +433,13 @@ void CliInterface::readStdout(bool handleAll)
     //freeze waiting for input. So we check for errors on the last line in
     //all cases.
     bool foundErrorMessage =
-        (checkForErrorMessage(lines.last(), WrongPasswordPatterns) ||
-         checkForErrorMessage(lines.last(), ExtractionFailedPatterns) ||
-         checkForFileExistsMessage(lines.last()));
+        (checkForErrorMessage(QLatin1String( lines.last() ), WrongPasswordPatterns) ||
+         checkForErrorMessage(QLatin1String( lines.last() ), ExtractionFailedPatterns) ||
+         checkForFileExistsMessage(QLatin1String( lines.last() )));
 
-    if (foundErrorMessage)
+    if (foundErrorMessage) {
         handleAll = true;
+    }
 
     //this is complex, here's an explanation:
     //if there is no newline, then there is no guaranteed full line to
@@ -458,8 +460,9 @@ void CliInterface::readStdout(bool handleAll)
     }
 
     foreach(const QByteArray& line, lines) {
-        if (!line.isEmpty())
+        if (!line.isEmpty()) {
             handleLine(QString::fromLocal8Bit(line));
+        }
     }
 }
 
@@ -467,7 +470,7 @@ void CliInterface::handleLine(const QString& line)
 {
     if ((m_operationMode == Copy || m_operationMode == Add) && m_param.contains(CaptureProgress) && m_param.value(CaptureProgress).toBool()) {
         //read the percentage
-        int pos = line.indexOf('%');
+        int pos = line.indexOf(QLatin1Char( '%' ));
         if (pos != -1 && pos > 1) {
             int percentage = line.mid(pos - 2, 2).toInt();
             progress(float(percentage) / 100);
@@ -491,8 +494,9 @@ void CliInterface::handleLine(const QString& line)
             return;
         }
 
-        if (handleFileExistsMessage(line))
+        if (handleFileExistsMessage(line)) {
             return;
+        }
     }
 
     if (m_operationMode == List) {
@@ -511,8 +515,9 @@ void CliInterface::handleLine(const QString& line)
             return;
         }
 
-        if (handleFileExistsMessage(line))
+        if (handleFileExistsMessage(line)) {
             return;
+        }
 
         readListLine(line);
         return;
@@ -524,12 +529,12 @@ bool CliInterface::findProgramAndCreateProcess(const QString& program)
     m_program = KStandardDirs::findExe(program);
 
     if (m_program.isEmpty()) {
-        error(i18n("Failed to locate program '%1' in PATH.", program));
+        error(i18nc("@info", "Failed to locate program <filename>%1</filename> in PATH.", program));
         return false;
     }
 
     if (!createProcess()) {
-        error(i18n("Found program '%1', but failed to initialize the process.", program));
+        error(i18nc("@info", "Found program <filename>%1</filename>, but failed to initialize the process.", program));
         return false;
     }
 
@@ -551,12 +556,13 @@ bool CliInterface::checkForFileExistsMessage(const QString& line)
 
 bool CliInterface::handleFileExistsMessage(const QString& line)
 {
-    if (!checkForFileExistsMessage(line))
+    if (!checkForFileExistsMessage(line)) {
         return false;
+    }
 
     const QString filename = m_existsPattern.cap(1);
 
-    Kerfuffle::OverwriteQuery query(QDir::current().path() + '/' + filename);
+    Kerfuffle::OverwriteQuery query(QDir::current().path() + QLatin1Char( '/' ) + filename);
     query.setNoRenameMode(true);
     userQuery(&query);
     kDebug() << "Waiting response";
@@ -567,20 +573,21 @@ bool CliInterface::handleFileExistsMessage(const QString& line)
     QString responseToProcess;
     const QStringList choices = m_param.value(FileExistsInput).toStringList();
 
-    if (query.responseOverwrite())
+    if (query.responseOverwrite()) {
         responseToProcess = choices.at(0);
-    else if (query.responseSkip())
+    } else if (query.responseSkip()) {
         responseToProcess = choices.at(1);
-    else if (query.responseOverwriteAll())
+    } else if (query.responseOverwriteAll()) {
         responseToProcess = choices.at(2);
-    else if (query.responseAutoSkip())
+    } else if (query.responseAutoSkip()) {
         responseToProcess = choices.at(3);
-    else if (query.responseCancelled())
+    } else if (query.responseCancelled()) {
         responseToProcess = choices.at(4);
+    }
 
     Q_ASSERT(!responseToProcess.isEmpty());
 
-    responseToProcess += '\n';
+    responseToProcess += QLatin1Char( '\n' );
 
     kDebug() << "Writing " << responseToProcess;
 
@@ -597,8 +604,9 @@ bool CliInterface::checkForErrorMessage(const QString& line, int parameterIndex)
     if (patternCache.contains(parameterIndex)) {
         patterns = patternCache.value(parameterIndex);
     } else {
-        if (!m_param.contains(parameterIndex))
+        if (!m_param.contains(parameterIndex)) {
             return false;
+        }
 
         foreach(const QString& rawPattern, m_param.value(parameterIndex).toStringList()) {
             patterns << QRegExp(rawPattern);
@@ -619,8 +627,9 @@ bool CliInterface::doKill()
     if (m_process) {
         m_process->terminate();
 
-        if (!m_process->waitForFinished())
+        if (!m_process->waitForFinished()) {
             m_process->kill();
+        }
 
         m_process->waitForFinished();
 
@@ -645,7 +654,7 @@ void CliInterface::substituteListVariables(QStringList& params)
     for (int i = 0; i < params.size(); ++i) {
         const QString parameter = params.at(i);
 
-        if (parameter == "$Archive") {
+        if (parameter == QLatin1String( "$Archive" )) {
             params[i] = filename();
         }
     }
@@ -669,8 +678,9 @@ QString CliInterface::escapeFileName(const QString& fileName)
     quoted.reserve(len * 2);
 
     for (int i = 0; i < len; ++i) {
-        if (m_escapedCharacters.contains(fileName.at(i)))
+        if (m_escapedCharacters.contains(fileName.at(i))) {
             quoted.append(backslash);
+        }
 
         quoted.append(fileName.at(i));
     }
