@@ -2,17 +2,13 @@
 // Author: Klaus Niederkrueger <kniederk@math.uni-koeln.de>
 //
 
-#include <stdlib.h>
-#include <stdio.h>
-
-#include <iostream>
-
-
 #include "knumbertest.h"
-
+#include <cstdlib>
+#include <cstdio>
+#include <iostream>
 #include <QString>
 
-QString const  numtypeToString(KNumber::NumType arg)
+QString numtypeToString(KNumber::NumType arg)
 {
     switch (arg) {
     case KNumber::SpecialType:
@@ -29,8 +25,8 @@ QString const  numtypeToString(KNumber::NumType arg)
     }
 }
 
-void checkResult(QString const &string, KNumber const & result,
-                 QString const & desired_string, KNumber::NumType desired)
+void checkResult(const QString &string, const KNumber &result,
+                 const QString &desired_string, KNumber::NumType desired)
 {
     std::cout << "Testing result of: " << string.toAscii().constData() <<
               " should give " << desired_string.toAscii().constData() << " and gives " <<
@@ -49,7 +45,7 @@ void checkResult(QString const &string, KNumber const & result,
     exit(1);
 }
 
-void checkTruth(QString const &string, bool computation,
+void checkTruth(const QString &string, bool computation,
                 bool desired_result)
 {
     std::cout << "Testing truth of: " << string.toAscii().constData() <<
@@ -66,7 +62,7 @@ void checkTruth(QString const &string, bool computation,
 }
 
 
-void checkType(QString const &string, KNumber::NumType test_arg,
+void checkType(const QString &string, KNumber::NumType test_arg,
                KNumber::NumType desired)
 {
     std::cout << "Testing type of: " << string.toAscii().constData() << " should give " <<
@@ -84,7 +80,7 @@ void checkType(QString const &string, KNumber::NumType test_arg,
 }
 
 
-void testingCompare(void)
+void testingCompare()
 {
     std::cout << "\n\nTesting Compare:\n";
 
@@ -128,7 +124,7 @@ void testingCompare(void)
 }
 
 
-void testingAdditions(void)
+void testingAdditions()
 {
     std::cout << "\n\nTesting additions:\n";
 
@@ -148,7 +144,7 @@ void testingAdditions(void)
 
 }
 
-void testingSubtractions(void)
+void testingSubtractions()
 {
     std::cout << "\n\nTesting subtractions:\n";
 
@@ -169,7 +165,7 @@ void testingSubtractions(void)
 }
 
 
-void testingMultiplications(void)
+void testingMultiplications()
 {
     std::cout << "\n\nTesting multiplications:\n";
 
@@ -193,7 +189,7 @@ void testingMultiplications(void)
 
 }
 
-void testingDivisions(void)
+void testingDivisions()
 {
     std::cout << "\n\nTesting divisions:\n";
 
@@ -225,7 +221,7 @@ void testingDivisions(void)
     checkResult("KNumber(-5.5) / KNumber(0.0)", KNumber(-5.5) / KNumber(0.0), "-inf", KNumber::SpecialType);
 }
 
-void testingModulus(void)
+void testingModulus()
 {
     std::cout << "\n\nTesting modulus:\n";
 
@@ -241,7 +237,7 @@ void testingModulus(void)
 
 }
 
-void testingAndOr(void)
+void testingAndOr()
 {
     std::cout << "\n\nTesting And/Or:\n";
 
@@ -257,7 +253,7 @@ void testingAndOr(void)
 }
 
 
-void testingAbs(void)
+void testingAbs()
 {
     std::cout << "\n\nTesting absolute value:\n";
 
@@ -270,7 +266,7 @@ void testingAbs(void)
     checkResult("KNumber(\"-2.3\").abs()", KNumber("-2.3").abs(), "2.3", KNumber::FloatType);
 }
 
-void testingTruncateToInteger(void)
+void testingTruncateToInteger()
 {
     std::cout << "\n\nTesting truncate to an integer:\n";
 
@@ -282,7 +278,7 @@ void testingTruncateToInteger(void)
 }
 
 
-void testingSqrt(void)
+void testingSqrt()
 {
     std::cout << "\n\nTesting square root, cubic root:\n";
 
@@ -310,7 +306,7 @@ void testingSqrt(void)
 
 }
 
-void testingFactorial(void)
+void testingFactorial()
 {
     std::cout << "\n\nTesting factorial:\n";
 
@@ -341,7 +337,7 @@ void testingFactorial(void)
     checkResult("KNumber(3.5).factorial()", KNumber(3.5).factorial(), "6", KNumber::IntegerType);
 }
 
-// void testingComplement(void)
+// void testingComplement()
 // {
 //   std::cout << "\n\nTesting complement:\n";
 
@@ -362,7 +358,7 @@ void testingFactorial(void)
 //   checkResult("KNumber\"-1/2\").complement()", KNumber("-1/2").complement(), "nan", KNumber::SpecialType);
 // }
 
-void testingShifts(void)
+void testingShifts()
 {
     std::cout << "\n\nTesting left/right shift:\n";
 
@@ -371,7 +367,7 @@ void testingShifts(void)
 
 }
 
-void testingPower(void)
+void testingPower()
 {
     std::cout << "\n\nTesting Power:\n";
 
@@ -407,7 +403,7 @@ void testingPower(void)
     checkResult("KNumber(-5.5) ^ KNumber(0.0)", KNumber(-5.5).power(KNumber(0.0)), "1", KNumber::IntegerType);
 }
 
-void testingInfArithmetic(void)
+void testingInfArithmetic()
 {
     std::cout << "\n\nTesting inf/nan-arithmetics:\n";
 
@@ -543,7 +539,7 @@ void testingInfArithmetic(void)
     checkResult("mininf / KNumber(0.0)", tmp_mininf / KNumber(0.0), "-inf", KNumber::SpecialType);
 }
 
-void testingFloatPrecision(void)
+void testingFloatPrecision()
 {
     KNumber::setDefaultFloatPrecision(100);
     checkResult("Precision >= 100: (KNumber(1) + KNumber(\"1e-80\")) - KNumber(1)",
@@ -557,7 +553,7 @@ void testingFloatPrecision(void)
 
 }
 
-void testingOutput(void)
+void testingOutput()
 {
     KNumber::setDefaultFloatOutput(false);
     checkResult("Fractional output: KNumber(\"1/4\")", KNumber("1/4"), "1/4", KNumber::FractionType);
@@ -577,7 +573,7 @@ void testingOutput(void)
 }
 
 
-int main(void)
+int main()
 {
     std::cout << "Testing Constructors:\n";
 
