@@ -17,7 +17,7 @@
 #include <KLocale>
 #include <QApplication>
 
-#include "kpimutils/email.h"
+#include <kpimutils/email.h>
 
 KGpgGenerateKey::KGpgGenerateKey(QObject *parent, const QString &name, const QString &email, const QString &comment,
 		const KgpgCore::KgpgKeyAlgo &algorithm, const uint size, const unsigned int expire,
@@ -112,9 +112,7 @@ KGpgGenerateKey::postStart()
 		setSuccess(TS_USER_ABORTED);
 	}
 	QApplication::setOverrideCursor(Qt::BusyCursor);
-	keymessage.append("%commit");
-
-	write(keymessage);
+	write("%commit");
 }
 
 bool
@@ -159,6 +157,8 @@ KGpgGenerateKey::nextLine(const QString &line)
 	} else if (line.contains(QLatin1String( "GET_" ))) {
 		setSuccess(TS_MSG_SEQUENCE);
 		result = true;
+	} else if (line.contains(QLatin1String("KEY_NOT_CREATED"))) {
+		result = true;
 	}
 
 	emit statusMessage(msg);
