@@ -16,11 +16,15 @@
 #include <QByteArray>
 #include <QStringList>
 
+#include <KDebug>
 #include <KLocale>
 
 #include "gpgproc.h"
 #include "kgpginterface.h"
 
+// define this to get the commands and replies from all GnuPG transactions logged
+#undef KGPG_DEBUG_TRANSACTIONS
+
 class KGpgTransactionPrivate: QObject {
 public:
 	KGpgTransactionPrivate(KGpgTransaction *parent, bool allowChaining);
@@ -46,8 +50,18 @@ public:
 	int m_inputProcessResult;
 	bool m_ownProcessFinished;
 
+	/**
+	 * terminate GnuPG session
+	 */
+	void sendQuit(void);
+
+	void write(const QByteArray &a);
+
 private:
 	void processDone();
+
+	unsigned int m_quitTries;	///< how many times we tried to quit
+	QStringList m_quitLines;	///< what we received after we tried to quit
 };
 
 KGpgTransactionPrivate::KGpgTransactionPrivate(KGpgTransaction *parent, bool allowChaining)
@@ -60,7 +74,8 @@ KGpgTransactionPrivate::KGpgTransactionPrivate(KGpgTransaction *parent, bool all
 	m_chainingAllowed(allowChaining),
 	m_inputProcessDone(false),
 	m_inputProcessResult(KGpgTransaction::TS_OK),
-	m_ownProcessFinished(false)
+	m_ownProcessFinished(false),
+	m_quitTries(0)
 {
 }
 
@@ -90,6 +105,12 @@ KGpgTransactionPrivate::slotReadReady()
 	QString line;
 
 	while (m_process->readln(line, true) >= 0) {
+		if (m_quitTries)
+			m_quitLines << line;
+#ifdef KGPG_DEBUG_TRANSACTIONS
+		kDebug(2100) << line;
+#endif /* KGPG_DEBUG_TRANSACTIONS */
+
 		if (line.startsWith(QLatin1String("[GNUPG:] USERID_HINT "))) {
 			m_parent->addIdHint(line);
 		} else if (line.startsWith(QLatin1String("[GNUPG:] BAD_PASSPHRASE "))) {
@@ -97,17 +118,20 @@ KGpgTransactionPrivate::slotReadReady()
 		} else if (line.startsWith(QLatin1String("[GNUPG:] GET_BOOL "))) {
 			switch (m_parent->boolQuestion(line.mid(18))) {
 			case KGpgTransaction::BA_YES:
-				m_process->write("YES\n");
+				write("YES\n");
 				break;
 			case KGpgTransaction::BA_NO:
-				m_process->write("NO\n");
+				write("NO\n");
 				break;
 			case KGpgTransaction::BA_UNKNOWN:
 				m_parent->setSuccess(KGpgTransaction::TS_MSG_SEQUENCE);
-				m_process->write("quit\n");
+				kDebug(2100) << "unexpected GnuPG request" << line;
+				sendQuit();
 			}
+		} else if (line.startsWith(QLatin1String("[GNUPG:] CARDCTRL "))) {
+			// just ignore them, pinentry should handle that
 		} else if (m_parent->nextLine(line)) {
-			m_process->write("quit\n");
+			sendQuit();
 		}
 	}
 }
@@ -128,6 +152,20 @@ KGpgTransactionPrivate::slotProcessStarted()
 	m_parent->postStart();
 }
 
+void
+KGpgTransactionPrivate::sendQuit(void)
+{
+	write("quit\n");
+
+	if (m_quitTries++ >= 3) {
+		kDebug(2100) << "tried" << m_quitTries << "times to quit the GnuPG session";
+		kDebug(2100) << "last input was" << m_quitLines;
+		kDebug(2100) << "please file a bug report at https://bugs.kde.org";
+		m_process->kill();
+		m_success = KGpgTransaction::TS_MSG_SEQUENCE;
+	}
+}
+
 void
 KGpgTransactionPrivate::slotInputTransactionDone(int result)
 {
@@ -140,6 +178,15 @@ KGpgTransactionPrivate::slotInputTransactionDone(int result)
 		processDone();
 }
 
+void
+KGpgTransactionPrivate::write(const QByteArray &a)
+{
+	m_process->write(a);
+#ifdef KGPG_DEBUG_TRANSACTIONS
+	kDebug(2100) << a;
+#endif /* KGPG_DEBUG_TRANSACTIONS */
+}
+
 void
 KGpgTransactionPrivate::processDone()
 {
@@ -171,9 +218,10 @@ KGpgTransaction::start()
 void
 KGpgTransaction::write(const QByteArray &a, const bool lf)
 {
-	d->m_process->write(a);
 	if (lf)
-		d->m_process->write("\n");
+		d->write(a + '\n');
+	else
+		d->write(a);
 }
 
 void
@@ -245,13 +293,13 @@ KGpgTransaction::postStart()
 void
 KGpgTransaction::addIdHint(QString txt)
 {
-	int cut = txt.indexOf(' ', 22, Qt::CaseInsensitive);
+	int cut = txt.indexOf(QLatin1Char( ' ' ), 22, Qt::CaseInsensitive);
 	txt.remove(0, cut);
 
-	if (txt.contains('(', Qt::CaseInsensitive))
-		txt = txt.section('(', 0, 0) + txt.section(')', -1);
+	if (txt.contains(QLatin1Char( '(' ), Qt::CaseInsensitive))
+		txt = txt.section(QLatin1Char( '(' ), 0, 0) + txt.section(QLatin1Char( ')' ), -1);
 
-	txt.replace('<', "&lt;");
+	txt.replace(QLatin1Char( '<' ), QLatin1String( "&lt;" ));
 
 	if (!d->m_idhints.contains(txt))
 		d->m_idhints << txt;
@@ -260,7 +308,7 @@ KGpgTransaction::addIdHint(QString txt)
 QString
 KGpgTransaction::getIdHints() const
 {
-	return d->m_idhints.join(i18n(" or "));
+	return d->m_idhints.join( i18n(" or " ));
 }
 
 GPGProc *
@@ -338,7 +386,7 @@ KGpgTransaction::askPassphrase(const QString &message)
 	if (userIDs.isEmpty())
 		userIDs = i18n("[No user id found]");
 	else
-		userIDs.replace('<', "&lt;");
+		userIDs.replace(QLatin1Char( '<' ), QLatin1String( "&lt;" ));
 
 	if (d->m_tries < 3)
 		passdlgmessage = i18np("<p><b>Bad passphrase</b>. You have 1 try left.</p>", "<p><b>Bad passphrase</b>. You have %1 tries left.</p>", d->m_tries);
@@ -356,7 +404,7 @@ KGpgTransaction::askPassphrase(const QString &message)
 void
 KGpgTransaction::setGnuPGHome(const QString &home)
 {
-	d->m_process->setEnv("GNUPGHOME", home);
+	d->m_process->setEnv(QLatin1String( "GNUPGHOME" ), home);
 }
 
 int
@@ -414,4 +462,9 @@ KGpgTransaction::hasInputTransaction() const
 	return (d->m_inputTransaction != NULL);
 }
 
+void KGpgTransaction::kill()
+{
+	d->m_process->kill();
+}
+
 #include "kgpgtransaction.moc"
