@@ -31,7 +31,7 @@ class Q3ListViewItem;
 class QCheckBox;
 class KWalletEntryList;
 class KWMapEditor;
-
+class KAction;
 class WalletWidget : public QWidget, public Ui::WalletWidget
 {
 public:
@@ -58,7 +58,6 @@ class KWalletEditor : public KXmlGuiWindow {
 		void deleteFolder();
 
 	private slots:
-		void layout();
 		void updateFolderList(bool checkEntries = false);
 		void entrySelectionChanged(Q3ListViewItem *item);
 		void listItemRenamed(Q3ListViewItem *, int, const QString&);
@@ -104,7 +103,7 @@ class KWalletEditor : public KXmlGuiWindow {
 		bool _walletIsOpen;
 		QAction *_newFolderAction, *_deleteFolderAction;
 		QAction *_passwordAction, *_exportAction, *_saveAsAction, *_mergeAction, *_importAction;
-		QAction *_newEntryAction, *_renameEntryAction, *_deleteEntryAction;
+		KAction *_newEntryAction, *_renameEntryAction, *_deleteEntryAction;
 		QAction *_copyPassAction;
 		QLabel*_details;
 		QString _currentFolder;
@@ -114,6 +113,7 @@ class KWalletEditor : public KXmlGuiWindow {
 		QCheckBox *_mapEditorShowHide;
 		bool _newWallet;
 		KMenu *_contextMenu;
+        Q3ListViewItem *_displayedItem; // used to find old item when selection just changed
 };
 
 #endif
